@@ -1,10 +1,9 @@
 # -*- coding: UTF-8 -*-
-import sys
 
 from netmiko import ConnectHandler
 from collections import namedtuple
 
-class base_cisco_ios(object):
+class base_cisco(object):
     def __init__(self,ac_info,dev_info):
         self.username = ac_info.username
         self.password = ac_info.password
@@ -13,14 +12,7 @@ class base_cisco_ios(object):
         self.dev_name = dev_info.dev_name
         self.ip = dev_info.dev_ip
 
-
-    def account_verification(self, config_mode_tag="config"):
-        """
-        验证账号是否有配置权限，返回提示符
-        :param
-        :return: string
-        """
-        dev_info = {
+        self.dev_info = {
             'device_type': 'cisco_asa',
             'ip': self.ip,
             'username': self.username,
@@ -30,8 +22,16 @@ class base_cisco_ios(object):
             'timeout': 3600,
             'verbose': True,
         }
-        net_connect = ConnectHandler(**dev_info)
 
+
+
+    def account_verification(self, config_mode_tag="config"):
+        """
+        验证账号是否有配置权限，返回提示符
+        :param
+        :return: string
+        """
+        net_connect = ConnectHandler(**self.dev_info)
         net_connect.enable()
         prompt_info = net_connect.find_prompt()
         net_connect.config_mode()
@@ -45,17 +45,8 @@ class base_cisco_ios(object):
         :selected param running_content = 'Key'
         :return: string
         """
-        dev_info = {
-            'device_type': 'cisco_asa',
-            'ip': self.ip,
-            'username': self.username,
-            'password': self.password,
-            'port': 22,
-            'secret': self.enable_pass,
-            'timeout': 3600,
-            'verbose': True,
-        }
-        net_connect = ConnectHandler(**dev_info)
+
+        net_connect = ConnectHandler(**self.dev_info)
         net_connect.send_command("terminal length 0")
         net_connect.enable()
         if filter_str == 'NULL':
@@ -73,18 +64,7 @@ class base_cisco_ios(object):
         :param check_list
         :return: string
         """
-        # 第一步，连接到设备
-        dev_info = {
-            'device_type': "cisco_asa",
-            'ip': self.ip,
-            'username': self.username,
-            'password': self.password,
-            'port': 22,
-            'secret': self.enable_pass,
-            'timeout': 3600,
-            'verbose': True,
-        }
-        net_connect = ConnectHandler(**dev_info)
+        net_connect = ConnectHandler(**self.dev_info)
         net_connect.send_command("terminal length 0")
         net_connect.enable()
         check_result = ""
@@ -104,17 +84,8 @@ class base_cisco_ios(object):
         :return: True or False
         """
         if isinstance(check_list,str) : check_list = check_list.split("\n")
-        dev_info = {
-            'device_type': "cisco_asa",
-            'ip': self.ip,
-            'username': self.username,
-            'password': self.password,
-            'port': 22,
-            'secret': self.enable_pass,
-            'timeout': 3600,
-            'verbose': True,
-        }
-        net_connect = ConnectHandler(**dev_info)
+
+        net_connect = ConnectHandler(**self.dev_info)
         net_connect.send_command("terminal length 0")
         net_connect.enable()
         check_result = ""
@@ -132,27 +103,24 @@ class base_cisco_ios(object):
         :param route_list: ["xxx","xxx"]
         :return: list
         """
-        dev_info = {
-            'device_type': "cisco_asa",
-            'ip': self.ip,
-            'username': self.username,
-            'password': self.password,
-            'port': 22,
-            'secret': self.enable_pass,
-            'timeout': 3600,
-            'verbose': True,
-        }
-        net_connect = ConnectHandler(**dev_info)
+        if access_script_list == [] :
+            return False
+
+        net_connect = ConnectHandler(**self.dev_info)
         net_connect.send_config_set(access_script_list)
         net_connect.save_config()
         net_connect.disconnect()
         return True
 
 
-class asa_5545(base_cisco_ios):
-    def gen_routing_policy(self):
-        return []
+class cisco_asa_5545(base_cisco):
+    pass
 
-class cisco_C3900(base_cisco_ios):
-    def gen_routing_policy(self):
-        return []
+class cisco_3900(base_cisco):
+    pass
+
+class cisco_4500(base_cisco):
+    pass
+
+class cisco_3800(base_cisco):
+    pass
\ No newline at end of file
