@@ -11,15 +11,7 @@ class base_hs(object):
 
         self.dev_name = dev_info.dev_name
         self.ip = dev_info.dev_ip
-    
-
-    def account_verification(self, config_mode_tag="config"):
-        """
-        验证账号是否有配置权限，返回提示符
-        :param
-        :return: string
-        """
-        dev_info = {
+        self.dev_info = {
             'device_type': 'autodetect',
             'ip': self.ip,
             'username': self.username,
@@ -29,7 +21,14 @@ class base_hs(object):
             'timeout': 3600,
             'verbose': True,
         }
-        net_connect = ConnectHandler(**dev_info)
+
+    def account_verification(self, config_mode_tag="config"):
+        """
+        验证账号是否有配置权限，返回提示符
+        :param
+        :return: string
+        """
+        net_connect = ConnectHandler(**self.dev_info)
         net_connect.find_prompt()                  # 这句看似没用，但是如果没有，就会报错
         net_connect.write_channel("configure\n")
         net_connect.find_prompt()                  # 这句看似没用，但是如果没有，就会报错
@@ -48,17 +47,7 @@ class base_hs(object):
         :selected param running_content = 'Key'
         :return: string
         """
-        dev_info = {
-            'device_type': 'autodetect',
-            'ip': self.ip,
-            'username': self.username,
-            'password': self.password,
-            'port': 22,
-            'secret': self.enable_pass,
-            'timeout': 3600,
-            'verbose': True,
-        }
-        net_connect = ConnectHandler(**dev_info)
+        net_connect = ConnectHandler(**self.dev_info)
         net_connect.send_command("terminal length 0")
         if filter_str == 'NULL':
             running_config = net_connect.send_command(show_config_cmd)
@@ -75,18 +64,7 @@ class base_hs(object):
         :param check_list
         :return: string
         """
-        # 第一步，连接到设备
-        dev_info = {
-            'device_type': "autodetect",
-            'ip': self.ip,
-            'username': self.username,
-            'password': self.password,
-            'port': 22,
-            'secret': self.enable_pass,
-            'timeout': 3600,
-            'verbose': True,
-        }
-        net_connect = ConnectHandler(**dev_info)
+        net_connect = ConnectHandler(**self.dev_info)
         net_connect.send_command("terminal length 0")
         check_result = ""
         for line in check_list:
@@ -104,17 +82,8 @@ class base_hs(object):
         :return: True or False
         """
         if isinstance(check_list,str) : check_list = check_list.split("\n")
-        dev_info = {
-            'device_type': "autodetect",
-            'ip': self.ip,
-            'username': self.username,
-            'password': self.password,
-            'port': 22,
-            'secret': self.enable_pass,
-            'timeout': 3600,
-            'verbose': True,
-        }
-        net_connect = ConnectHandler(**dev_info)
+
+        net_connect = ConnectHandler(**self.dev_info)
         net_connect.send_command("terminal length 0")
         check_result = ""
         for line in check_list:
@@ -146,17 +115,10 @@ class base_hs(object):
         :param route_list: ["xxx","xxx"]
         :return: list
         """
-        dev_info = {
-            'device_type': "autodetect",
-            'ip': self.ip,
-            'username': self.username,
-            'password': self.password,
-            'port': 22,
-            'secret': self.enable_pass,
-            'timeout': 3600,
-            'verbose': True,
-        }
-        net_connect = ConnectHandler(**dev_info)
+        if access_script_list == [] :
+            return False
+
+        net_connect = ConnectHandler(**self.dev_info)
         net_connect.send_command("terminal length 0")
         net_connect.write_channel("configure\n")
 
@@ -172,6 +134,5 @@ class base_hs(object):
 
 
 class hs_SG6000(base_hs):
-    def gen_routing_policy(self):
-        return []
-
+    # def gen_routing_policy(self):
+    pass
