@@ -12,14 +12,7 @@ class base_huawei(object):
         self.dev_name = dev_info.dev_name
         self.ip = dev_info.dev_ip
 
-
-    def account_verification(self, config_mode_tag="]"):
-        """
-        验证账号是否有配置权限，返回提示符
-        :param
-        :return: string
-        """
-        dev_info = {
+        self.dev_info = {
             'device_type': 'huawei',
             'ip': self.ip,
             'username': self.username,
@@ -28,7 +21,14 @@ class base_huawei(object):
             'timeout': 3600,
             'verbose': True,
         }
-        net_connect = ConnectHandler(**dev_info)
+
+    def account_verification(self, config_mode_tag="]"):
+        """
+        验证账号是否有配置权限，返回提示符
+        :param
+        :return: string
+        """
+        net_connect = ConnectHandler(**self.dev_info)
         net_connect.config_mode(config_command="system-view")
 
         if config_mode_tag in net_connect.find_prompt():
@@ -46,16 +46,7 @@ class base_huawei(object):
         :selected param running_content = 'Key'
         :return: string
         """
-        dev_info = {
-            'device_type': 'huawei',
-            'ip': self.ip,
-            'username': self.username,
-            'password': self.password,
-            'port': 22,
-            'timeout': 3600,
-            'verbose': True,
-        }
-        net_connect = ConnectHandler(**dev_info)
+        net_connect = ConnectHandler(**self.dev_info)
         net_connect.send_command("screen-length 0 temporary")
         if filter_str == 'NULL':
             running_config = net_connect.send_command(show_config_cmd)
@@ -72,17 +63,7 @@ class base_huawei(object):
         :param check_list
         :return: string
         """
-        # 第一步，连接到设备
-        dev_info = {
-            'device_type': "huawei",
-            'ip': self.ip,
-            'username': self.username,
-            'password': self.password,
-            'port': 22,
-            'timeout': 3600,
-            'verbose': True,
-        }
-        net_connect = ConnectHandler(**dev_info)
+        net_connect = ConnectHandler(**self.dev_info)
         net_connect.send_command("screen-length 0 temporary")
         check_result = ""
         for line in check_list:
@@ -93,15 +74,6 @@ class base_huawei(object):
 
 
 
-    def inspect_session(self, check_list):
-        """
-        该函数可以检查防火墙的session，check_list是一个ip列表，可以检查该ip相关的session
-        返回保存了检查结果的字符串
-        :param
-        :return: True or False
-        """
-        return False
-
 
     def execute_script(self, access_script_list, mode="]"):
         """
@@ -110,17 +82,10 @@ class base_huawei(object):
         :param route_list: ["xxx","xxx"]
         :return: list
         """
-        dev_info = {
-            'device_type': "huawei",
-            'ip': self.ip,
-            'username': self.username,
-            'password': self.password,
-            'port': 22,
-            'timeout': 3600,
-            'verbose': True,
-        }
-        net_connect = ConnectHandler(**dev_info)
+        if access_script_list == [] :
+            return False
 
+        net_connect = ConnectHandler(**self.dev_info)
         if mode == ">":
             import time
             for cmd_line in access_script_list:
@@ -139,6 +104,31 @@ class base_huawei(object):
             net_connect.disconnect()
             return True
 
+
+
 class huawei_S5720(base_huawei):
     def gen_routing_policy(self):
         return []
+
+
+
+class huawei_usg(base_huawei):
+    # def gen_routing_policy(self):
+    '''
+    def inspect_session(self, check_list):
+        """
+        该函数可以检查防火墙的session，check_list是一个ip列表，可以检查该ip相关的session
+        返回保存了检查结果的字符串
+        :param
+        :return: True or False
+        """
+        net_connect = ConnectHandler(**self.dev_info)
+        net_connect.send_command("screen-length 0 temporary")
+        check_result = ""
+        for line in check_list:
+            show_configs = net_connect.send_command("display local-host " + line)
+            check_result = check_result + show_configs + "\n"
+        net_connect.disconnect()
+        return check_result
+    '''
+    pass
\ No newline at end of file
